<?php
/**
 * $Horde: imp/acl.php,v 1.2 $
 *
 * Copyright 2000-2003 Chris Hastie <imp@oak-wood.co.uk>
 *
 * See the enclosed file COPYING for license information (GPL).  If you
 * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
 */
define('IMP_BASE', dirname(__FILE__));
$authentication = OP_HALFOPEN;
require_once IMP_BASE . '/lib/base.php';
require_once IMP_BASE . '/lib/Acl.php';
require_once IMP_BASE . '/lib/Folder.php';

/* Redirect back to the options screen if acl is not
   allowed. */
if ($prefs->isLocked('acl')) {
    $notification->push(_("Folder sharing is disabled"), 'horde.error');
    header('Location: ' . Horde::applicationUrl('prefs.php', true));
    exit;
}

$AclDriver = IMP_Acl::singleton('rfc2086');
/* Check selected driver is supported. Redirect to options screen with error
   message if not */
$driverSupported = $AclDriver->isSupported;
$protected  = $AclDriver->protected;

if (!$driverSupported){
    $notification->push(_("This server does not support sharing folders."), 'horde.error');
    header('Location: ' . Horde::applicationUrl('prefs.php', true));
    exit;
}

/* Don't bother if it's not an IMAP server */
if ($_SESSION['imp']['base_protocol'] == 'imap') {

    $ok_form = true;
    $acl = Horde::getFormData('acl');
    
    
    /* Run through the action handlers */
    $actionID = Horde::getFormData('actionID');
    switch ($actionID) {

    case IMP_ACL_SET:
        if(!($share_user = Horde::getFormData('share_user'))) {
            $notification->push(_("No user specified"), 'horde.error');   
            $ok_form = false;
        }
        if(!($folder = Horde::getFormData('folder'))) {
            $notification->push(_("No folder selected"), 'horde.error');   
            $ok_form = false;
        }
        if(in_array($share_user, $protected)) {
            $notification->push(_("Permissions for this user can not be changed"), 'horde.error');   
            $ok_form = false;
        }   
        
        if ($ok_form){
            $result = $AclDriver->createAcl($folder, $share_user, $acl);
            if ($result == "no_support") {
                header('Location: ' . Horde::applicationUrl('prefs.php', true));
                exit;            
            }
        }
        break;
        
    case IMP_ACL_EDIT:
        if(!($share_user = Horde::getFormData('share_user'))) {
            $notification->push(_("No user specified"), 'horde.error');   
            $ok_form = false;
        }
        if(!($folder = Horde::getFormData('folder'))) {
            $notification->push(_("No folder selected"), 'horde.error');   
            $ok_form = false;
        }
        if(in_array($share_user, $protected)) {
            $notification->push(_("Permissions for this user can not be changed"), 'horde.error');   
            $ok_form = false;
        }       
    
        if ($ok_form){
            $result = $AclDriver->editAcl($folder, $share_user, $acl);
            if ($result == "no_support") {
                header('Location: ' . Horde::applicationUrl('prefs.php', true));
                exit;            
            }
        }
        break;    

    }
    $imp_folder = &IMP_Folder::singleton();
    $rights = $AclDriver->rightsList;
    
    if (count($imp_folder->flist_IMP())) {
        $options = IMP::flistSelect(_("Change Folder"), true);
    }
    
    if (empty($folder)) {
        $folder = 'INBOX';
    } 
        
    $curr_acl = array();
    $curr_acl = $AclDriver->getAcl($folder);
    $canEdit = $AclDriver->canEdit($curr_acl, $_SESSION['imp']['user']);
    
    /* Set up javascript arrays. */
    if (count($curr_acl)) {
        $js_user = '';
        foreach ($rights as $right => $desc) {
            $js_right[$right] = '';
        }
        
        foreach ($curr_acl as $curr_user => $granted) {
            if (strlen($js_user) > 0) {
                $js_user .= ', ';
                foreach ($rights as $right => $desc) {
                    $js_right[$right] .= ', ';
                }
            }

            $js_user .= '"'.$curr_user.'"';
            
            foreach ($rights as $right => $desc) {
                if (array_key_exists($right, $granted) && ($granted[$right] > 0)) {
                    $js_right[$right] .= '"1"';
                } else {
                    $js_right[$right] .= '"0"';
                }
            }
        }
    }
       
} else {
    $notification->push( _("Folder sharing is only available with IMAP servers"), 'horde.error');
    header('Location: ' . Horde::applicationUrl('prefs.php', true));
    exit;    
}

$title = _("Share Folders");
$js_onLoad = null;
require IMP_TEMPLATES . '/common-header.inc';
require IMP_BASE . '/menu.php';
require IMP_BASE . '/status.php';

require IMP_TEMPLATES . '/acl/javascript.inc';
require IMP_TEMPLATES . '/acl/list.inc';
require IMP_TEMPLATES . '/acl/manage.inc';

require IMP_TEMPLATES . '/common-footer.inc';
